@@ -1,4 +1,4 @@
-tm1_get_native_view <- function(tm1_connection, cube="", view="", RowElementAsColumn = TRUE) {
+tm1_get_native_view <- function(tm1_connection, cube="", view="", RowElementAsColumn = FALSE) {
 
   tm1_adminhost <- tm1_connection$adminhost
   tm1_httpport <- tm1_connection$port
@@ -20,8 +20,6 @@ tm1_get_native_view <- function(tm1_connection, cube="", view="", RowElementAsCo
   u7 <- "')/Views('"
   u8 <- view
   u9 <- "')/tm1.Execute"
-  #u10 <- "?$expand=Cells"
-  u10 <- ""
   u10 <- "?$expand=Axes($expand=Tuples($expand=Members($select=Name,UniqueName))),Cells($select=Value)"
 
 
@@ -44,11 +42,11 @@ tm1_get_native_view <- function(tm1_connection, cube="", view="", RowElementAsCo
   tm1_return <- jsonlite::fromJSON(httr::content(tm1_process_return, "text"))
 
   # get number of dimension elements of view
-  ncols <- tm1_return$Axes[1,2]
-  nrows <- tm1_return$Axes[2,2]
+  ncols <- tm1_return$Axes$Cardinality[1]
+  nrows <- tm1_return$Axes$Cardinality[2]
 
   # get data from return
-  tm1_data <- tm1_return$Cells[2][[1]]
+  tm1_data <- tm1_return$Cells$Value
 
   # fill NAs with zero data
   tm1_data[is.na(tm1_data)] <- 0
@@ -58,40 +56,30 @@ tm1_get_native_view <- function(tm1_connection, cube="", view="", RowElementAsCo
   tm1_view_matrix <- as.data.frame(tm1_view_matrix)
 
   # if there is no column elements, do not run assign
-  if(ncols > 1 || is.null(tm1_return$Axes[1,3][[1]]$Members[[1]]$Name)==FALSE)
-  {
-
+  if(is.null(tm1_return$Axes$Tuples[[1]]$Members[[1]]$Name) == FALSE){
     for (i in 1:ncols)
-      {
-        colname <- tm1_return$Axes[1,3][[1]]$Members[[i]]$Name
-        colnames(tm1_view_matrix)[i] <- paste(colname, collapse = "|")
-      }
-  }
-
-  # if there is no column elements, assign value to 1 column
-  if (ncols ==1)
+    {
+      colname <- tm1_return$Axes$Tuples[[1]]$Members[[i]]$Name
+      colnames(tm1_view_matrix)[i] <- paste(colname, collapse = "|")
+    }
+  } else {
     colnames(tm1_view_matrix)[1] <- "Value"
+  }
 
 
   # if there is no rown elements, do not run assign
-  if(nrows > 1 || is.null(tm1_return$Axes[2,3][[1]]$Members[[1]]$Name)==FALSE)
-  {
+  if(is.null(tm1_return$Axes$Tuples[[2]]$Members[[1]]$Name) == FALSE){
     for (j in 1:nrows)
     {
-      rowname <- tm1_return$Axes[2,3][[1]]$Members[[j]]$Name
+      rowname <- tm1_return$Axes$Tuples[[2]]$Members[[j]]$Name
       rownames(tm1_view_matrix)[j] <- paste(rowname, collapse = "|")
     }
+  } else {
+    rownames(tm1_view_matrix)[1] <- "Value"
   }
 
-  # if there is no row elements, assign value to 1 row
-  if (nrows ==1)
-    rownames(tm1_view_matrix)[1] <- "Value"
-
-  # change to matrix if there is only numeric inside matrix because matrix is better and faster
-  tm1_view_matrix <- as.matrix(tm1_view_matrix)
-
-  # add row elements as column at the end
-  tm1_view_rowelements <- cbind(as.data.frame(tm1_view_matrix), rownames(tm1_view_matrix))
+    # add row elements as column at the end
+  tm1_view_rowelements <- cbind(tm1_view_matrix, rownames(tm1_view_matrix))
 
   # get a data frame from row elements
   tm1_rowelements <- strsplit(as.character(tm1_view_rowelements$"rownames(tm1_view_matrix)"),'|', fixed = TRUE)
@@ -105,18 +93,18 @@ tm1_get_native_view <- function(tm1_connection, cube="", view="", RowElementAsCo
   for(i in 1:ncol(tm1_rowelements_seperate))
   {
     #colnames(tm1_rowelements_seperate)[i] <- paste("Dim",as.character(i),sep="")
-    dimfullname <- tm1_return$Axes[2,3][[1]]$Members[[1]]$UniqueName[i]
+    dimfullname <- tm1_return$Axes$Tuples[[2]]$Members[[1]]$UniqueName[i]
     colnames(tm1_rowelements_seperate)[i] <- substr(dimfullname, 2, regexpr("]", dimfullname, fixed = TRUE)[1]-1)
   }
 
   # combine data and elements data frames
-  tm1_view_dataframe <- cbind(as.data.frame(tm1_view_matrix), tm1_rowelements_seperate)
+  tm1_view_dataframe <- cbind(tm1_view_matrix, tm1_rowelements_seperate)
   rownames(tm1_view_dataframe) <- NULL
 
 
   # if parameter is FALSE, return data only matrix
   if( RowElementAsColumn == FALSE || nrows == 1)
-    return(as.data.frame(tm1_view_matrix))
+    return(tm1_view_matrix)
   # if parameter is TRUE, return data.frame including data and elements
   else
     return(tm1_view_dataframe)
